/****************************************************************************
 *																			*
 * File    : srcview.c														*
 *																			*
 * Purpose : Sample add-in DLL. View project file in hex dump editor.		*
 *																			*
 * History : Date	   Reason												*
 *			 04-01-10  Created												*
 *																			*
 ****************************************************************************/

#define WIN32_LEAN_AND_MEAN
#include <windows.h>
//#include <windowsx.h>
#include <addin.h>
#include "srcview.h"

// Private command ID - any number will do.
#define ID_OPENSRC  1

#pragma nodefaultlib
#pragma comment(lib, "libctiny.lib");

// Locals.
static HANDLE g_hmod = NULL;
static HWND g_hwndMain = NULL;

/****************************************************************************
 *																			*
 * Function: DllMain														*
 *																			*
 * Purpose : DLL entry and exit procedure.									*
 *																			*
 * History : Date	   Reason												*
 *			 04-01-10  Created												*
 *																			*
 ****************************************************************************/

BOOL WINAPI DllMain(HANDLE hDLL, DWORD dwReason, LPVOID lpReserved)
{
	switch (dwReason)
	{
		case DLL_PROCESS_ATTACH:
			g_hmod = hDLL;
			return TRUE;

		case DLL_PROCESS_DETACH:
			return TRUE;

		default:
			return TRUE;
	}
}

/****************************************************************************
 *																			*
 * Function: AddInMain														*
 *																			*
 * Purpose : Add-in entry and exit procedure.								*
 *																			*
 * History : Date	   Reason												*
 *			 04-01-10  Created												*
 *			 04-10-08  Moved command from button to context menu.			*
 *																			*
 ****************************************************************************/

ADDINAPI BOOL WINAPI AddInMain(HWND hwnd, ADDIN_EVENT eEvent)
{
	switch (eEvent)
	{
		case AIE_APP_CREATE:
		{
			ADDIN_ADD_COMMAND AddCmd = {0};

			/* Save handle of main IDE window */
			g_hwndMain = hwnd;

			/* Add command to project context menu */
			AddCmd.cbSize = sizeof(AddCmd);
			AddCmd.pszText = "Open in source editor";  // Menu text.
			AddCmd.hIcon = LoadImage(g_hmod, MAKEINTRESOURCE(IDR_ICON1), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR|LR_SHARED);  // Menu icon.
			AddCmd.id = ID_OPENSRC;
			AddCmd.idMenu = AIM_MENU_PROJECT_CONTEXT;  // Project context menu.
			return AddIn_AddCommand(hwnd, &AddCmd);
		}

		case AIE_APP_DESTROY:
			/* Remove from project context menu */
			return AddIn_RemoveCommand(hwnd, ID_OPENSRC);

		default:
			return TRUE;
	}
}

/****************************************************************************
 *																			*
 * Function: AddInCommand													*
 *																			*
 * Purpose : Add-in command handler.										*
 *																			*
 * History : Date	   Reason												*
 *			 04-01-10  Created												*
 *			 04-10-08  Changed to AddInCommandEx with new logic.			*
 *																			*
 ****************************************************************************/

ADDINAPI void WINAPI AddInCommandEx(int idCmd, LPCVOID pcvData)
{
	switch (idCmd)
	{
		case ID_OPENSRC:
		{
			/* Verify that the passed argument is in fact a string */
			if (!IsBadStringPtr(pcvData, 260))
			{
				/* OK, open the file in the hexdump editor */
				AddIn_OpenDocument(g_hwndMain, AID_SOURCE, (PCTSTR)pcvData);
			}
			break;
		}
	}
}
